@@ -572,7 +572,7 @@ struct isoburn_imgen_opts {
     /**
      * Write AAIP as extension according to SUSP 1.10 rather than SUSP 1.12.
      * I.e. without announcing it by an ER field and thus without the need
-     * to preceed the RRIP fields by an ES and to preceed the AA field by ES.
+     * to precede the RRIP fields by an ES and to precede the AA field by ES.
      */
     unsigned int aaip_susp_1_10 :1;
 
@@ -710,6 +710,11 @@ struct isoburn_imgen_opts {
     */
     int part_like_isohybrid;
 
+    /* See libisoburn.h isoburn_igopt_set_gpt_guid()
+    */
+    uint8_t gpt_guid[16];
+    int gpt_guid_mode;
+
     /* Eventual name of the non-ISO aspect of the image. E.g. SUN ASCII label.
      */
     char ascii_disc_label[Libisoburn_disc_label_sizE];
