@@ -151,6 +151,7 @@ int isoburn_read_image(struct burn_drive *d,
  enum burn_disc_status status= BURN_DISC_BLANK;
  IsoDataSource *ds= NULL;
  struct isoburn *o= NULL;
+ IsoImage *new_image= NULL;
 
  msg= calloc(1, 160);
 
@@ -189,6 +190,7 @@ create_blank_image:;
      }
      iso_image_set_ignore_aclea(*image,
                          (!!(read_opts->noacl)) | ((!!read_opts->noea) << 1) );
+     new_image= *image;
    } else {
      /* Blank new image for the drive */
      iso_image_unref(o->image);
@@ -207,7 +209,12 @@ create_blank_image:;
      ret= isoburn_root_defaults(o->image, 0);
      if(ret <= 0)
        goto ex;
+     new_image= o->image;
    }
+   ret= iso_image_set_truncate_mode(new_image, read_opts->truncate_mode,
+                                    read_opts->truncate_length);
+   if(ret < 0)
+     goto ex;
    {ret= 1; goto ex;}
  }
  
@@ -268,6 +275,8 @@ displacement_rollover:;
  else
    int_num= 0;
  iso_read_opts_set_no_md5(ropts, int_num);
+ if(read_opts->do_ecma119_map)
+   iso_read_opts_set_ecma119_map(ropts, read_opts->map_mode);
  iso_read_opts_set_new_inos(ropts, read_opts->noino);
 
  iso_read_opts_set_no_joliet(ropts, read_opts->nojoliet);
@@ -281,6 +290,10 @@ displacement_rollover:;
  iso_read_opts_auto_input_charset(ropts, read_opts->auto_input_charset);
  iso_read_opts_load_system_area(ropts, 1);
  iso_read_opts_keep_import_src(ropts, 1);
+ ret= iso_image_set_truncate_mode(o->image, read_opts->truncate_mode,
+                                  read_opts->truncate_length);
+ if(ret < 0)
+   goto ex;
 
  ds = isoburn_data_source_new(d, read_opts->displacement,
                          read_opts->displacement_sign,
@@ -299,6 +312,7 @@ displacement_rollover:;
    iso_tree_set_report_callback(o->image, NULL);
  else
    iso_tree_set_report_callback(o->image, o->read_pacifier);
+ 
  ret = iso_image_import(o->image, ds, ropts, &features);
  iso_tree_set_report_callback(o->image, NULL);
  iso_read_opts_free(ropts);
@@ -656,11 +670,32 @@ ex:;
 */
 int isoburn_invalidate_iso(struct isoburn *o, int flag)
 {
+ int end_ed_found= 0, i;
+ char *head;
+
+ head= (char *) o->target_iso_head;
  /* 
   * replace CD001 with CDXX1 in PVM.
   * I think this is enought for invalidating an iso image
   */
- strncpy((char*)o->target_iso_head + 16 * 2048 + 1, "CDXX1", 5);
+ strncpy(head + 16 * 2048 + 1, "CDXX1", 5);
+
+ /* Look for UDF volume recognition sequence and invalidate */
+ for(i= 17 * 2048; i < 32 * 2048; i+= 2048) {
+   if(end_ed_found) {
+     if(head[i] == 0 && strncmp(head + i + 1, "BEA01", 5) == 0)
+       strncpy(head + i + 1, "BEAX1", 5);
+     else if(head[i] == 0 && strncmp(head + i + 1, "NSR", 3) == 0)
+       strncpy(head + i + 1, "NSRX", 4);
+     else if(head[i] == 0 && strncmp(head + i + 1, "TEA", 3) == 0) 
+       strncpy(head + i + 1, "TEAX", 4);
+   } else {
+     if(((unsigned char *) head)[i] == 0xff &&
+        strncmp(head + i + 1, "CD001", 5) == 0)
+       end_ed_found= 1;
+   }
+ }
+
  return isoburn_activate_session(o->drive);
 }
 
