@@ -383,9 +383,7 @@ int iso_get_rr_name(IsoWriteOpts *opts, char *input_charset,
             iso_msg_submit(imgid, ISO_FILENAME_WRONG_CHARSET, ret,
                    "Charset conversion error. Cannot convert %s from %s to %s",
                    str, input_charset, output_charset);
-
-        /* use the original name, it's the best we can do */
-        ret = iso_clone_mem(str, name, 0);
+        *name = NULL;
         return ISO_FILENAME_WRONG_CHARSET;
     }
 
@@ -579,12 +577,15 @@ int rrip_add_SL(Ecma119Image *t, struct susp_info *susp, uint8_t **comp,
              * debug purposes
              */
             if (ce == 0) {
+                free(SL);
                 return ISO_ASSERT_FAILURE;
             }
             ret = susp_append_ce(t, susp, SL);
             if (ret < 0) {
+                free(SL);
                 return ret;
             }
+            SL = NULL; /* now owned by susp */
             written = i;
             total_comp_len = comp[i][1] + 2;
         }
@@ -1179,9 +1180,12 @@ int susp_calc_nm_sl_al(Ecma119Image *t, Ecma119Node *n, size_t space,
         }
     }
 
+    namelen = 0;
     name = get_rr_fname(t, n->node->name);
-    namelen = strlen(name);
-    free(name);
+    if (name != NULL) {
+        namelen = strlen(name);
+        free(name);
+    }
 
     if (flag & 1) {
        /* Account for 28 bytes of CE field */
@@ -1741,9 +1745,15 @@ int rrip_get_susp_fields(Ecma119Image *t, Ecma119Node *n, int type,
         uint8_t **comps= NULL; /* components of the SL field */
         size_t n_comp = 0; /* number of components */
 
+        namelen = 0;
         name = get_rr_fname(t, n->node->name);
+        if (name == NULL)
+            name = strdup("");
+        if (name == NULL) {
+            ret = ISO_OUT_OF_MEM;
+            goto add_susp_cleanup;
+        }
         namelen = strlen(name);
-
         sua_free = space - info->suf_len;
 
         /* Try whether NM, SL, AL will fit into SUA */
@@ -1787,6 +1797,13 @@ int rrip_get_susp_fields(Ecma119Image *t, Ecma119Node *n, int type,
             int cew = (nm_type == 1); /* are we writing to CE? */
 
             dest = get_rr_fname(t, ((IsoSymlink*)n->node)->dest);
+            if (dest == NULL)
+                dest = strdup("");
+            if (dest == NULL) {
+                ret = ISO_OUT_OF_MEM;
+                goto add_susp_cleanup;
+            }
+
             prev = dest;
             cur = strchr(prev, '/');
             while (1) {
@@ -2122,8 +2139,10 @@ int rrip_get_susp_fields(Ecma119Image *t, Ecma119Node *n, int type,
     return ISO_SUCCESS;
 
     add_susp_cleanup: ;
-    free(name);
-    free(dest);
+    if (name != NULL)
+        free(name);
+    if (dest != NULL)
+        free(dest);
     susp_info_free(info);
     return ret;
 }
