@@ -251,6 +251,8 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->buffer_timeout_sec= 120;
  m->min_buffer_percent= 90;
  m->max_buffer_percent= 95;
+ m->use_immed_bit= 0;
+ m->use_immed_bit_default= 0;
  m->stdio_sync= 0;
  m->stdio_sync_is_default= 1;
  m->keep_boot_image= 0;
@@ -290,6 +292,8 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->appended_as_gpt= 0;
  m->appended_as_apm= 0;
  m->part_like_isohybrid= 0;
+ memset(m->gpt_guid, 0, 16);
+ m->gpt_guid_mode= 0;
  m->ascii_disc_label[0]= 0;
  m->grub2_sparc_core[0]= 0;
  memset(m->hfsp_serial_number, 0, 8);
@@ -300,6 +304,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->vol_expiration_time= 0;
  m->vol_effective_time= 0;
  m->vol_uuid[0]= 0;
+ m->all_file_dates[0]= 0;
 
 #ifdef Xorriso_with_libjtE
  m->libjte_handle= NULL;
