@@ -463,6 +463,7 @@ int Decode_ecma119_format(struct tm *erg, char *text, int flag)
 /* 2010040711405800 */
 {
  int i, l, num, utc= 1;
+ struct tm norm_tm;
 
  memset(erg, 0, sizeof(*erg));
  erg->tm_isdst= -1;
@@ -499,6 +500,11 @@ int Decode_ecma119_format(struct tm *erg, char *text, int flag)
  erg->tm_sec= 10*(text[12]-'0')+text[13]-'0';
  if(erg->tm_sec > 59)
    return(0);
+ /* Let mktime(3) compute erg->tm_wday and erg->tm_yday */
+ memcpy(&norm_tm, erg, sizeof(struct tm));
+ mktime(&norm_tm);
+ erg->tm_wday= norm_tm.tm_wday;
+ erg->tm_yday= norm_tm.tm_yday;
  return(1 + !utc);
 }
 
@@ -1077,10 +1083,12 @@ int Hex_to_bin(char *hex,
  int i, l, acc;
 
  l= strlen(hex);
- if(l % 2 || l == 0)
+ if(((l % 2) && l < 2 * bin_size) || l == 0)
    return(-1); /* malformed */
  *bin_count= 0;
  for(i= 0; i < l; i+= 2) {
+   if(*bin_count >= bin_size)
+     return(0); /* overflow */
    if(hex[i] >= '0' && hex[i] <= '9')
      acc= (hex[i] - '0') << 4;
    else if(hex[i] >= 'A' && hex[i] <= 'F')
@@ -1097,8 +1105,6 @@ int Hex_to_bin(char *hex,
      acc|= (hex[i + 1] - 'a' + 10);
    else
      return(-1);
-   if(*bin_count >= bin_size)
-     return(0); /* overflow */
    bin_data[*bin_count]= acc;
    (*bin_count)++;
  }
