@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2015 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2016 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -541,11 +541,12 @@ int Xorriso_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "prog","prog_help","publisher","quoted_not_list","quoted_path_list",
     "read_fs","read_speed","reassure","report_about",
     "report_el_torito","report_system_area","rockridge",
-    "rom_toc_scan","rr_reloc_dir","scsi_log",
+    "rom_toc_scan","rr_reloc_dir","scsi_dev_family","scsi_log",
     "session_log","sh_style_result","signal_handling","sleep",
     "speed","split_size","status","status_history_max",
     "stdio_sync","stream_recording","system_id","temp_mem_limit","toc_of",
-    "uid","unregister_filter","use_readline","volid","volset_id",
+    "uid","unregister_filter","use_immed_bit","use_readline",
+    "volid","volset_id",
     "write_type","xattr","zisofs",
     ""
  };
@@ -680,11 +681,12 @@ int Xorriso_cmd_sorting_rank(struct XorrisO *xorriso,
    "ecma119_map",
    "disk_dev_ino", "rom_toc_scan", "calm_drive", "ban_stdio_write",
    "early_stdio_test", "data_cache_size",
+   "scsi_dev_family",
 
    "* Character sets:",
    "charset", "local_charset",
 
-   "* Aquiring source and target drive:",
+   "* Acquiring source and target drive:",
    "dev", "indev", "outdev",
 
    "* Drive and media related inquiry actions (2):",
@@ -738,7 +740,7 @@ int Xorriso_cmd_sorting_rank(struct XorrisO *xorriso,
    "abstract_file", "biblio_file", "preparer_id", "application_use",
    "out_charset", "read_mkisofsrc",
    "uid", "gid", "zisofs", "speed", "stream_recording", "dvd_obs",
-   "modesty_on_drive",
+   "modesty_on_drive", "use_immed_bit",
    "stdio_sync", "dummy", "fs", "close", "padding", "write_type",
    "grow_blindly", "pacifier", "scdbackup_tag",
 
@@ -922,7 +924,7 @@ ex:
                bit1= these are command line arguments
                      (for xorriso->argument_emulation)
                bit2= Only execute the one command argv[*idx] and advance 
-                     *idx to the next command if sucessful. Then return.
+                     *idx to the next command if successful. Then return.
 */
 int Xorriso_interpreter(struct XorrisO *xorriso,
                         int argc, char **argv, int *idx, int flag)
@@ -1721,6 +1723,10 @@ next_command:;
    (*idx)+= 2;
    ret= Xorriso_option_scdbackup_tag(xorriso, arg1, arg2, 0);
  
+ } else if(strcmp(cmd, "scsi_dev_family") == 0) {
+   (*idx)++;
+   ret= Xorriso_option_scsi_dev_family(xorriso, arg1, 0);
+
  } else if(strcmp(cmd, "scsi_log") == 0) {
    (*idx)++;
    ret= Xorriso_option_scsi_log(xorriso, arg1, 0);
@@ -1928,6 +1934,10 @@ if (0) {
    (*idx)+= 2;
    ret= Xorriso_option_update(xorriso, arg1, arg2, 1|8);
 
+ } else if(strcmp(cmd,"use_immed_bit")==0) {
+   (*idx)++;
+   ret= Xorriso_option_use_immed_bit(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"use_readline")==0) {
    (*idx)++;
    ret= Xorriso_option_use_readline(xorriso, arg1, 0);
@@ -2072,9 +2082,8 @@ int Xorriso_execute_option(struct XorrisO *xorriso, char *line, int flag)
  char **argv= NULL;
  double tdiff;
  struct timeval tv;
- struct timezone tz;
 
- gettimeofday(&tv,&tz);
+ gettimeofday(&tv, NULL);
  Xorriso_reset_counters(xorriso,0);
  xorriso->idle_time= 0.0;
  tdiff= tv.tv_sec+(1.e-6*(double) tv.tv_usec);
@@ -2091,7 +2100,7 @@ int Xorriso_execute_option(struct XorrisO *xorriso, char *line, int flag)
  ret= Xorriso_interpreter(xorriso, argc, argv, &idx, flag&0xffff);
  if(ret<0)
    goto ex;
- gettimeofday(&tv,&tz);
+ gettimeofday(&tv, NULL);
  tdiff= tv.tv_sec+(1.e-6*(double) tv.tv_usec)-tdiff-xorriso->idle_time;
  if(tdiff<0.001)
    tdiff= 0.001;
@@ -2540,10 +2549,70 @@ ex:;
 }
 
 
+/* https://reproducible-builds.org/specs/source-date-epoch/
+   and reproducible-builds@lists.alioth.debian.org in august 2016
+*/
+int Xorriso_source_date_epoch(struct XorrisO *xorriso, int flag)
+{
+ char *sec_text, double_text[40];
+ double dsec= -1.0;
+ time_t tsec;
+ struct tm *gmt;
+
+ sec_text= getenv("SOURCE_DATE_EPOCH");
+ if(sec_text == NULL)
+   return(2);
+
+ sscanf(sec_text, "%lf", &dsec);
+ sprintf(double_text, "%.f", dsec);
+ tsec= dsec;
+ if(dsec < 0 || ((double) tsec) != dsec ||
+    strcmp(sec_text, double_text) != 0) {
+malformed:;
+   Xorriso_msgs_submit(xorriso, 0,
+                "Malformed environment variable SOURCE_DATE_EPOCH encountered",
+                       0, "SORRY", 0);
+   Xorriso_msgs_submit(xorriso, 0,
+                "Unset SOURCE_DATE_EPOCH before starting xorriso or see https://reproducible-builds.org/specs/source-date-epoch/",
+                       0, "HINT", 0);
+   return(0);
+ }
+ gmt= gmtime(&tsec);
+ if(gmt == NULL)
+   goto malformed;
+ sprintf(xorriso->vol_uuid, "%4.4d%2.2d%2.2d%2.2d%2.2d%2.2d00",
+         1900 + gmt->tm_year, gmt->tm_mon + 1, gmt->tm_mday,
+         gmt->tm_hour, gmt->tm_min, gmt->tm_sec);
+ xorriso->gpt_guid_mode= 2; /* Disk GUID from vol_uuid */
+ strcpy(xorriso->all_file_dates, "set_to_mtime");
+ sprintf(xorriso->info_text,
+         "Environment variable SOURCE_DATE_EPOCH encountered with value %s",
+         sec_text);
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "NOTE", 0);
+ sprintf(xorriso->info_text, "SOURCE_DATE_EPOCH : -volume_date uuid %s",
+                             xorriso->vol_uuid);
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "DEBUG", 0);
+ sprintf(xorriso->info_text,
+                          "SOURCE_DATE_EPOCH : -volume_date all_file_dates %s",
+                          xorriso->all_file_dates);
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "DEBUG", 0);
+ sprintf(xorriso->info_text,
+                       "SOURCE_DATE_EPOCH : -boot_image any volume_date_uuid");
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "DEBUG", 0);
+ return(1);
+}
+
+
 int Xorriso_read_rc(struct XorrisO *xorriso, int flag)
 {
  int ret,i,was_failure= 0,fret;
 
+ /* Interpret environment variable SOURCE_DATE_EPOCH */
+ ret= Xorriso_source_date_epoch(xorriso, 0);
+ ret= Xorriso_eval_problem_status(xorriso, ret, 0);
+ if(ret < 0)
+   return(0);
+
  if(xorriso->no_rc)
    return(1);
  i= xorriso->rc_filename_count-1;
