@@ -74,7 +74,7 @@ struct XorrisO;
 */
 #define Xorriso_header_version_majoR  1
 #define Xorriso_header_version_minoR  4
-#define Xorriso_header_version_micrO  4
+#define Xorriso_header_version_micrO  6
 
 
 /** If needed: Something like ".pl01" to indicate a bug fix. Normally empty.
@@ -346,7 +346,7 @@ int Xorriso_program_arg_bsl(struct XorrisO *xorriso, int argc, char ***argv,
                         which where set with Xorriso_new(), or argument
                         arranging.
                   bit2= Only execute the one command argv[*idx] and advance
-                        *idx to the next command if sucessful. Then return.
+                        *idx to the next command if successful. Then return.
                         This prevents any argument arranging.
                         @since 1.2.2
                   bit3= With bit1 and not bit2:
@@ -2133,6 +2133,11 @@ int Xorriso_option_update(struct XorrisO *xorriso, char *disk_path,
 /* @since 0.1.0 */
 int Xorriso_option_use_readline(struct XorrisO *xorriso, char *mode, int flag);
 
+/* Command -use_immed_bit */
+/* @since 1.4.6 */
+int Xorriso_option_use_immed_bit(struct XorrisO *xorriso, char *mode,
+                                 int flag);
+
 /* Command -version */
 /* @since 0.1.0 */
 int Xorriso_option_version(struct XorrisO *xorriso, int flag);
