@@ -34,6 +34,9 @@
 #endif
 #endif
 
+/* for pthread_mutex_t on OpenBSD */
+#include <pthread.h>
+
 
 /** The source code release timestamp */
 #include "xorriso_timestamp.h"
@@ -300,7 +303,7 @@ struct XorrisO { /* the global context of xorriso */
  int cache_tile_blocks;
  int cache_default;       /* bit0= cache_num_tiles, bit1= cache_tile_blocks */
 
- int do_calm_drive;      /* bit0= calm down drive after aquiring it */
+ int do_calm_drive;      /* bit0= calm down drive after acquiring it */
 
  char indev[SfileadrL];
  void *in_drive_handle;  /* interpreted only by libburnia oriented modules */
@@ -380,6 +383,9 @@ struct XorrisO { /* the global context of xorriso */
  int min_buffer_percent;
  int max_buffer_percent;
 
+ int use_immed_bit;           /* 1= on , 0= default , -1 = off */
+ int use_immed_bit_default;   /* 1= on , 0= yet undefined , -1 = off */
+
  int stdio_sync;              /* stdio fsync interval: -1, 0, >=32 */
  int stdio_sync_is_default;   /* 1= is still default , 0= has been set */
 
@@ -491,6 +497,10 @@ struct XorrisO { /* the global context of xorriso */
  /* If 1: Apply isohybrid gestures to non-isohybrid situations */
  int part_like_isohybrid;
 
+ /* See libisoburn.h isoburn_igopt_set_gpt_guid() */
+ uint8_t gpt_guid[16];
+ int gpt_guid_mode;
+
  /* Eventual name of the non-ISO aspect of the image. E.g. SUN ASCII label.
  */
  char ascii_disc_label[Xorriso_disc_label_sizE];
@@ -518,6 +528,10 @@ struct XorrisO { /* the global context of xorriso */
  /* To eventually override vol_modification_time by unconverted string
     and timezone 0 */
  char vol_uuid[17];
+ /* To flatly set all file timestamps to the same value
+    Special value: "set_to_mtime", see -find action "set_to_mtime"
+  */
+ char all_file_dates[80];
 
 #ifdef Xorriso_with_libjtE
  /* Parameters and state of Jigdo Template Export environment */
@@ -611,7 +625,7 @@ struct XorrisO { /* the global context of xorriso */
  int structured_search;
  /* 0= flat text search
     1= '/' is a significant separator that cannot be matched by wildcards
-    ( 2= like 1 : but report only occurence in tree, no payload, no location )
+    ( 2= like 1 : but report only occurrence in tree, no payload, no location )
     ( 3= like 2 : but report first content level of matching directories )
     4= actually not structured but unique find mode (with search_mode 4)
  */
@@ -629,7 +643,7 @@ struct XorrisO { /* the global context of xorriso */
                         bit1= parameter too (else rekursion only)
                         bit2= whole subtree banned (else only exact path)
                         bit3= when comparing ignore excluded files rather
-                              than to treat them as truely missing on disk
+                              than to treat them as truly missing on disk
                      */
 
  struct ExclusionS *iso_rr_hidings;
