@@ -19,7 +19,7 @@
 */
 #define xorriso_libisoburn_req_major  1
 #define xorriso_libisoburn_req_minor  4
-#define xorriso_libisoburn_req_micro  4
+#define xorriso_libisoburn_req_micro  6
 
 
 struct SpotlisT;          /* List of intervals with different read qualities */
@@ -624,6 +624,8 @@ int Xorriso_pretend_full_disc(struct XorrisO *xorriso, int flag);
 
 int Xorriso_scsi_dev_family(struct XorrisO *xorriso, int flag);
 
+int Xorriso_use_immed_bit(struct XorrisO *xorriso, int flag);
+
 
 int Xorriso_apply_sort_file(struct XorrisO *xorriso, char *path, int flag);
 
@@ -640,5 +642,12 @@ int Xorriso_truncate_path_comps(struct XorrisO *xorriso, char *path,
 int Xorriso_graftable_pathspec(struct XorrisO *xorriso, char *in_pathspec,
                                char *pathspec, int flag);
 
+int Xorriso_parse_gpt_guid(struct XorrisO *xorriso, char *text, int flag);
+
+int Xorriso_format_guid(struct XorrisO *xorriso, uint8_t guid[16], char *line,
+                        int flag);
+
+int Xorriso_make_guid(struct XorrisO *xorriso, char *line, int flag);
+
 #endif /* Xorrisoburn_includeD */
 
